@@ -35,9 +35,9 @@ from git import Repo
 
 from dcicutils.env_utils import (
     get_standard_mirror_env, data_set_for_env, get_bucket_env, INDEXER_ENVS, is_fourfront_env, is_cgap_env,
-    FF_ENV_INDEXER, CGAP_ENV_INDEXER, is_indexer_env
+    FF_ENV_INDEXER, CGAP_ENV_INDEXER, is_indexer_env, indexer_env_for_env
 )
-from dcicutils.misc_utils import PRINT
+from dcicutils.misc_utils import PRINT, Retry
 
 # constants associated with EB-related APIs
 EB_CONFIGURATION_SETTINGS = 'ConfigurationSettings'
@@ -45,6 +45,7 @@ EB_OPTION_SETTINGS = 'OptionSettings'
 EB_ENV_VARIABLE_NAMESPACE = 'aws:elasticbeanstalk:application:environment'
 STATUS = 'Status'
 UPDATING = 'Updating'
+LAUNCHING = 'Launching'
 TERMINATING = 'Terminating'
 
 
@@ -226,6 +227,23 @@ class EBDeployer:
         configurable_options = env_settings[EB_OPTION_SETTINGS]
         return configurable_options
 
+    @classmethod
+    @Retry.retry_allowed(retries_allowed=1, wait_seconds=10)
+    def verify_template_creation(cls, client, template_name):
+        """ Does a get for the given template_name to verify EB has recognized that it is
+            available.
+
+        :param client: boto3 elasticbeanstalk client
+        :param template_name: name of template to check
+        :returns: True if template can be acquired
+        :raises: Exception if one is encountered
+        """
+        client.describe_configuration_settings(
+            ApplicationName=cls.EB_APPLICATION,
+            TemplateName=template_name
+        )
+        return True
+
     @classmethod
     def create_indexer_configuration_template(cls, env_name, size=None):
         """ Uploads an indexer configuration template to EB
@@ -263,20 +281,14 @@ class EBDeployer:
                                     configuration))
 
         # upload the template
-        if is_cgap_env(env_name):
-            return eb_client.create_configuration_template(
-                ApplicationName=cls.EB_APPLICATION,
-                TemplateName=CGAP_ENV_INDEXER,
-                OptionSettings=configuration,
-                EnvironmentId=cls.extract_environment_id(env_name)
-            )
-        else:
-            return eb_client.create_configuration_template(
-                ApplicationName=cls.EB_APPLICATION,
-                TemplateName=FF_ENV_INDEXER,
-                OptionSettings=configuration,
-                EnvironmentId=cls.extract_environment_id(env_name)
-            )
+        indexer_env = indexer_env_for_env(env_name)
+        eb_client.create_configuration_template(
+            ApplicationName=cls.EB_APPLICATION,
+            TemplateName=indexer_env,
+            OptionSettings=configuration,
+            EnvironmentId=cls.extract_environment_id(env_name)
+        )
+        return cls.verify_template_creation(eb_client, indexer_env)
 
     @classmethod
     def create_indexer_environment(cls, env_name, app_version):
@@ -295,14 +307,14 @@ class EBDeployer:
                 EnvironmentName=CGAP_ENV_INDEXER,
                 TemplateName=CGAP_ENV_INDEXER,
                 VersionLabel=app_version
-            )[STATUS] == UPDATING and cls.delete_indexer_template(eb_client, CGAP_ENV_INDEXER)
+            )[STATUS] == LAUNCHING and cls.delete_indexer_template(eb_client, CGAP_ENV_INDEXER)
         elif is_fourfront_env(env_name):
             return eb_client.create_environment(
                 ApplicationName=cls.EB_APPLICATION,
                 EnvironmentName=FF_ENV_INDEXER,
                 TemplateName=FF_ENV_INDEXER,
                 VersionLabel=app_version
-            )[STATUS] == UPDATING and cls.delete_indexer_template(eb_client, FF_ENV_INDEXER)
+            )[STATUS] == LAUNCHING and cls.delete_indexer_template(eb_client, FF_ENV_INDEXER)
         else:  # should never get here, but for good measure
             raise RuntimeError('Tried to deploy indexer from an unknown environment: %s' % env_name)
 
